﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'sv', {
	auto: 'Automatisk',
	bgColorTitle: 'Bakgrundsfärg',
	colors: {
		'000': 'Svart',
		'800000': 'Rödbrun',
		'8B4513': 'Mörkbrun',
		'2F4F4F': 'Skiffergrå',
		'008080': 'Kricka',
		'000080': 'Marinblå',
		'4B0082': 'Indigo',
		'696969': 'Mörkgrå',
		B22222: 'Tegelsten',
		A52A2A: 'Brun',
		DAA520: 'Mörk guld',
		'006400': 'Mörkgrön',
		'40E0D0': 'Turkos',
		'0000CD': 'Medium blå',
		'800080': 'Lila',
		'808080': 'Grå',
		F00: 'Röd',
		FF8C00: 'Mörkorange',
		FFD700: 'Guld',
		'008000': 'Grön',
		'0FF': 'Turkos',
		'00F': 'Blå',
		EE82EE: 'Violett',
		A9A9A9: 'Matt grå',
		FFA07A: 'Laxrosa',
		FFA500: 'Orange',
		FFFF00: 'Gul',
		'00FF00': 'Lime',
		AFEEEE: 'Ljusturkos',
		ADD8E6: 'Ljusblå',
		DDA0DD: 'Plommon',
		D3D3D3: 'Ljusgrå',
		FFF0F5: 'Ljus lavendel',
		FAEBD7: 'Antikvit',
		FFFFE0: 'Ljusgul',
		F0FFF0: 'Honungsdagg',
		F0FFFF: 'Azurblå',
		F0F8FF: 'Aliceblå',
		E6E6FA: 'Lavendel',
		FFF: 'Vit',
		'1ABC9C': 'Stark turkos',
		'2ECC71': 'Smaragd',
		'3498DB': 'Klarblå',
		'9B59B6': 'Ametist',
		'4E5F70': 'Gråblå',
		'F1C40F': 'Klargul',
		'16A085': 'Mörk turkos',
		'27AE60': 'Mörk smaragd',
		'2980B9': 'Stark blå',
		'8E44AD': 'Mörk violett',
		'2C3E50': 'Blek blå',
		'F39C12': 'Orange',
		'E67E22': 'Morot',
		'E74C3C': 'Blekröd',
		'ECF0F1': 'Stark silver',
		'95A5A6': 'Ljus gråaktig turkos',
		'DDD': 'Ljusgrå',
		'D35400': 'Pumpa',
		'C0392B': 'Stark röd',
		'BDC3C7': 'Silver',
		'7F8C8D': 'Gråaktig turkos',
		'999': 'Mörkgrå'
	},
	more: 'Fler färger...',
	panelTitle: 'Färger',
	textColorTitle: 'Textfärg'
} );
